/**
 * Copyright (C) 2010 Cloudfarming <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.geoviewer;

import com.vividsolutions.jts.geom.Geometry;
import org.geotools.coverage.grid.GridCoverage2D;

/**
 * A layer object represents an item in a layer.
 * The geometry of the object is used to determine the 
 * location where it should be drawn
 *
 * @author Timon Veenstra
 */
public interface LayerObject<G extends Geometry>  {

    /**
     * describes the geometry of the object
     * this can be a point, or a multipolygon
     *
     * @return
     */
    G getGeometry();

    /**
     *
     * @return
     */
    String getKey();

    /**
     *
     * @return
     */
    Object getKeyAttributeValue();

    /**
     * 
     * @return
     */
    String getTooltipText();

    /**
     * get the id of the wrapped object
     *
     * @return
     */
    Long getId();

}
